/*
  testterm.c

  June 18, 2015
  Code placed in Public Domain.  
  A device/sensor handler for the Raspberry Pi.
  Start out with a Sensirion sht11 module from Parallax.
  Moved to a DNA-RTC board for better voltage handling.
  Prototype for eventual(maybe) switch to a Propeller HAT.
  Things that may be added:
    -XBee module
    -DS18B20 temperature sensor, multiple modules.
    -CO2 sensor
    -How much can the Propeller HAT support?
*/
#include "simpletools.h"
#include "simpletext.h"
#include "fdserial.h"
#include "sht11.h"

serial *rpi;

/* Sensirion sht11 pins */
int  DatPin = 1;
int  ClkPin = 3;

sht11values_t MyVals;
sht11values_t *pMyVals;

volatile long Hum;
volatile long TmpC;
volatile long TmpF;
volatile long Status;
/***********************/

void Sensirion();  // New COG

int main()
{
  // Add startup code here.
  cog_run(Sensirion,128);  // Start the sht11 COG.
  pause(200);
  rpi = fdserial_open(19,20,0,115200);  // Raspberry Pi in this case.
  pause(50);

  char inBuff[40];

  //int message = 9999;  // Debug
  char outBuff[10];
     
  while(1)
  {
    // Add main loop code here.
      readStr(rpi, inBuff, 40);         // Waiting for incoming
      if(!strcmp(inBuff,"gettempf"))        // Checks the string
      {
        //sprintf(outBuff,"%d",message);  // Converts to ascii, Debug
        sprintf(outBuff,"%d",TmpF/10-3); // Use appropriate "%" for data
        writeLine(rpi,outBuff);         // RPi term program understands.
                                        // Sent with CR
      }
      if(!strcmp(inBuff,"gethumid"))
      {
        sprintf(outBuff,"%d",Hum/10);
        writeLine(rpi,outBuff);
      }                
      print("%s\n",inBuff);     // Local Debug         
  }  
}

/* Sensirion sht11 COG */
/* Drives the Sensirion sht11 every second for data refresh of module. */
void Sensirion()
{
// Moved to global declare area.
//long Hum;
//long TmpC;
//long TmpF;
//long Status;

  // Add startup code here.
  // Assign the address of our structure to the pointer
  pMyVals = &MyVals;
  high(16);   // Local Debug
  pause(1000);
  Start(DatPin,ClkPin,pMyVals);
  Status = ReadStatusReg();  
  while(1)
  {
    Measure();
    Hum = pMyVals->rhlin;   // % Humidity
    TmpC = pMyVals->tempC;  // C degrees
    TmpF = pMyVals->tempF;  // F degrees
    pause(1000);    

  }  
}


/*    Original Debug code, for comm with the freeBasic
      program on the Raspberry Pi.
      // Wait for key press from simpleide terminal
      getStr(locBuff, 40);
      writeLine(rpi,locBuff);  // Send it with CR
      // Displays incoming, up to 40 chars.
      readStr(rpi, inBuff, 40);
      print("%s\n",inBuff); 
*/